import { useAccount } from '@/utils/hooks';
import { removeToken } from '@/utils/token';
import { LogoutOutlined, UserOutlined } from '@ant-design/icons';
import { Avatar, Menu } from 'antd';
import { history } from 'umi';
import defaultSettings from '../../../config/defaultSettings';
import HeaderDropdown from '../HeaderDropdown';
import styles from './index.less';

export const MenuUser = ({ showName }: { showName?: boolean }) => {
  const { account, setAccount } = useAccount();

  const loginOut = () => {
    // 1、清空信息
    setAccount(undefined);
    // 2、删除Token
    removeToken();
    // 3、跳转页面
    history.push(`/passport/login`);
  };

  const handleClick = (key: string) => {
    if (key === 'user') {
      history.push(`/system/account`);
      return;
    }
    if (key === 'logout') {
      loginOut();
      return;
    }
  };

  const getMenus = () => {
    const menus = [];
    menus.push({ key: 'user', label: '我的账号', icon: <UserOutlined style={{ fontSize: 16 }} /> });
    menus.push({ type: 'divider' as const });
    menus.push({
      key: 'logout',
      label: `退出登录`,
      icon: <LogoutOutlined style={{ fontSize: 16 }} />,
    });
    return menus;
  };

  const menus = (
    <Menu
      style={{ minWidth: '140px', padding: 4 }}
      onClick={({ key }) => handleClick(key)}
      items={getMenus()}
    />
  );

  return (
    <HeaderDropdown overlay={menus}>
      <span className={styles.operate}>
        <span style={{ display: 'flex', alignItems: 'center', padding: '0 10px' }}>
          <Avatar
            size={28}
            icon={<UserOutlined />}
            style={{ backgroundColor: defaultSettings.primaryColor }}
          />
          {showName && <span style={{ margin: 8 }}>{account?.name}</span>}
        </span>
      </span>
    </HeaderDropdown>
  );
};
