import IconFont from '@/components/Icon/IconFont';
import { getImageUrl } from '@/utils/url';
import { Avatar } from 'antd';
import defaultSettings from '../../../../config/defaultSettings';

type BasicAvatarProps = {
  image?: string;
  icon?: string;
  color?: string;
  name?: string;
  size?: 'default' | 'large' | 'small' | 60 | 80 | 100 | 28;
  shape?: 'circle' | 'square';
  className?: string;
};

const BasicAvatar = ({ image, icon, color, name, size, shape, className }: BasicAvatarProps) => {
  const fontSize =
    size === 'large'
      ? '20px'
      : size === 'small'
      ? '14px'
      : size === 60
      ? '30px'
      : size === 80
      ? '40px'
      : size === 100
      ? '60px'
      : size === 28
      ? '18px'
      : '16px';

  return image ? (
    <Avatar
      size={size ? size : 'default'}
      src={getImageUrl(image)}
      shape={shape ? shape : 'circle'}
      className={className}
    />
  ) : icon ? (
    <Avatar
      size={size ? size : 'default'}
      style={{ backgroundColor: color }}
      icon={<IconFont type={icon} />}
      shape={shape ? shape : 'circle'}
      className={className}
    />
  ) : (
    <Avatar
      size={size ? size : 'default'}
      style={{ color: '#ffffff', backgroundColor: color || defaultSettings.primaryColor }}
      shape={shape ? shape : 'circle'}
      className={className}
    >
      <span style={{ fontSize }}>{name?.substring(0, 1)}</span>
    </Avatar>
  );
};

export default BasicAvatar;
