import { Button, Drawer } from 'antd';
import { useIntl } from 'umi';

export type BasicDrawerProps = {
  visible?: boolean;
  title?: React.ReactNode;
  onClose?: (e: any) => void;
  onOk?: (e: any) => void;
  okText?: React.ReactNode;
  width?: string | number;
  paddingTop?: number;
  paddingBottom?: number;
  children?: any;
};

const BasicDrawer = ({
  visible,
  title,
  width,
  onClose,
  onOk,
  okText,
  paddingTop,
  paddingBottom,
  children,
}: BasicDrawerProps) => {
  const intl = useIntl();

  return (
    <Drawer
      destroyOnClose
      open={visible}
      title={<span style={{ fontSize: 20 }}>{title}</span>}
      width={width}
      contentWrapperStyle={{ paddingTop, paddingBottom }}
      onClose={onClose && onClose}
      extra={
        onOk && (
          <Button type="primary" onClick={onOk}>
            {okText ? okText : intl.formatMessage({ id: 'operate.ok' })}
          </Button>
        )
      }
    >
      {children}
    </Drawer>
  );
};

export default BasicDrawer;
