import { ProCard } from '@ant-design/pro-components';
import { Layout, Menu } from 'antd';
import { useEffect, useState } from 'react';
import { history } from 'umi';
import styles from './index.less';

export type BasicMenuProps = {
  key: string;
  label: string;
  icon?: React.ReactNode;
  component: React.ReactNode;
};

const BasicMenu = ({ menus }: { menus: BasicMenuProps[] }) => {
  const tab = new URLSearchParams(window.location.search).get('tab');
  const currentKey = menus.find((item) => item.key === tab)?.key;
  const firstKey = menus.length > 0 ? menus[0].key : undefined;
  const [selected, setSelected] = useState<any>(currentKey ? currentKey : firstKey);

  useEffect(() => {
    setSelected(currentKey ? currentKey : firstKey);
  }, [currentKey, firstKey]);

  const menuRender = (mode: 'inline' | 'horizontal') => {
    return (
      <Menu
        mode={mode}
        selectedKeys={selected ? [selected] : undefined}
        onSelect={({ selectedKeys }) => {
          setSelected(selectedKeys[0]);
          history.push(`${window.location.pathname}?tab=${selectedKeys[0]}`);
        }}
        items={menus.map((item) => {
          return {
            key: item.key,
            label: item.label,
            icon: item.icon,
          };
        })}
      />
    );
  };

  const getMenu = (key?: string) => {
    return menus.find((item) => item.key === key);
  };

  return (
    <div>
      <Layout style={{ height: '100%' }}>
        <Layout.Sider
          breakpoint="md"
          collapsedWidth="0"
          trigger={null}
          width={180}
          style={{ height: '100%' }}
        >
          {menuRender('inline')}
        </Layout.Sider>
        <Layout.Content className={styles.right}>
          <div className={styles.menu}>{menuRender('horizontal')}</div>
          <ProCard title={<span className={styles.title}>{getMenu(selected)?.label}</span>}>
            {getMenu(selected)?.component}
          </ProCard>
        </Layout.Content>
      </Layout>
    </div>
  );
};

export default BasicMenu;
