import { Button, Modal, Space } from 'antd';
import { useIntl } from 'umi';

export type BasicModalProps = {
  visible?: boolean;
  title?: React.ReactNode;
  onCancel?: (e: any) => void;
  onOk?: (e: any) => void;
  cancelText?: React.ReactNode;
  okText?: React.ReactNode;
  cancelButtonProps?: object;
  okButtonProps?: object;
  hiddenFooter?: boolean;
  width?: string | number;
  children?: any;
};

const BasicModal = ({
  visible,
  title,
  onCancel,
  onOk,
  cancelText,
  okText,
  cancelButtonProps,
  okButtonProps,
  hiddenFooter,
  width,
  children,
}: BasicModalProps) => {
  const intl = useIntl();

  return (
    <Modal
      destroyOnClose
      footer={null}
      open={visible}
      onCancel={onCancel && onCancel}
      onOk={onOk && onOk}
      width={width}
    >
      <div style={{ marginTop: -12, paddingBottom: 24, fontSize: 20 }}>{title}</div>
      <div style={{ paddingBottom: 24 }}>{children}</div>
      {!hiddenFooter && (
        <div style={{ textAlign: 'right' }}>
          <Space>
            <Button
              type="text"
              onClick={onCancel && onCancel}
              {...(cancelButtonProps ? cancelButtonProps : {})}
            >
              {cancelText ? cancelText : intl.formatMessage({ id: 'operate.cancel' })}
            </Button>
            <Button type="primary" onClick={onOk && onOk} {...(okButtonProps ? okButtonProps : {})}>
              {okText ? okText : intl.formatMessage({ id: 'operate.ok' })}
            </Button>
          </Space>
        </div>
      )}
    </Modal>
  );
};

export default BasicModal;
