import Action from '@/components/Action';
import { ActionHome } from '@/components/Action/ActionHome';
import { LinkGoohier } from '@/components/Action/LinkGoohier';
import { MenuUser } from '@/components/Action/MenuUser';
import {
  WarningOutlined,
  BookOutlined,
  CarOutlined,
  CarryOutOutlined,
  ControlOutlined,
  FlagOutlined,
  HddOutlined,
  IdcardOutlined,
  MoneyCollectOutlined,
  NodeIndexOutlined,
  ProfileOutlined,
  SettingOutlined,
  TeamOutlined,
  ThunderboltOutlined,
  AuditOutlined,
  UserOutlined,
  UserSwitchOutlined,
  ToolOutlined,
  BulbOutlined,
  AimOutlined,
  DashboardOutlined,
  TransactionOutlined,
  MergeCellsOutlined,
} from '@ant-design/icons';
import { ProLayout } from '@ant-design/pro-components';
import { history, Outlet, useAccess, useLocation } from '@umijs/max';
import { useEffect, useState } from 'react';
import { ThemeStyle } from '@/components/Action/ThemeStyle';
import './index.less';

const BaseLayout = () => {
  const location = useLocation();
  const access = useAccess();
  const [menu, setMenu] = useState<any>([]);

  useEffect(() => {
    const menus = [
      {
        path: '/dashboard',
        name: '仪表板',
        icon: <DashboardOutlined />,
        hideInMenu: !access.canDashboard,
      },
      {
        path: '/customer',
        name: '客户查询',
        icon: <BookOutlined />,
        hideInMenu: !access.canCustomer,
        children: [
          {
            path: '/customer/order',
            name: '订单查询',
            icon: <ProfileOutlined />,
          },
          {
            path: '/customer/bill',
            name: '账单查询',
            icon: <MoneyCollectOutlined />,
          },
          {
            path: '/customer/vehicle',
            name: '车辆查询',
            icon: <CarOutlined />,
          },
          {
            path: '/customer/battery',
            name: '电池查询',
            icon: <HddOutlined />,
          },
          {
            path: '/customer/driver',
            name: '司机查询',
            icon: <UserSwitchOutlined />,
          },
        ],
      },
      {
        path: '/station',
        name: '电站监控',
        icon: <ThunderboltOutlined />,
        hideInMenu: !access.canStation,
        children: [
          {
            path: '/station/order',
            name: '订单查询',
            icon: <ProfileOutlined />,
          },
          {
            path: '/station/alarm',
            name: '设备告警',
            icon: <WarningOutlined />,
          },
          {
            path: '/station/power',
            name: '机组充电',
            icon: <BulbOutlined />,
          },
          {
            path: '/station/measure',
            name: '设备度量',
            icon: <AimOutlined />,
            hideInMenu: true,
          },
          {
            path: '/station/battery',
            name: '电站电池',
            icon: <HddOutlined />,
          },
          {
            path: '/station/device',
            name: '电站设备',
            icon: <MergeCellsOutlined />,
          },
        ],
      },
      {
        path: '/operator',
        name: '运营管理',
        icon: <FlagOutlined />,
        hideInMenu: !access.canOperator,
        children: [
          {
            path: '/operator/order',
            name: '订单管理',
            icon: <ProfileOutlined />,
          },
          {
            path: '/operator/bill',
            name: '账单管理',
            icon: <MoneyCollectOutlined />,
          },
          {
            path: '/operator/customer',
            name: '客户管理',
            icon: <IdcardOutlined />,
          },
          {
            path: '/operator/rule',
            name: '计费规则',
            icon: <NodeIndexOutlined />,
          },
          {
            path: '/operator/vehicle',
            name: '车辆管理',
            icon: <CarOutlined />,
          },
          {
            path: '/operator/battery',
            name: '电池管理',
            icon: <HddOutlined />,
          },
          {
            path: '/operator/device',
            name: '电站设备',
            icon: <MergeCellsOutlined />,
          },
          {
            path: '/operator/station',
            name: '电站查询',
            icon: <ThunderboltOutlined />,
          },
          {
            path: '/operator/price',
            name: '电网电价',
            icon: <TransactionOutlined />,
          },
        ],
      },
      {
        path: '/admin',
        name: '平台管理',
        icon: <ControlOutlined />,
        hideInMenu: !access.canAdmin,
        children: [
          {
            path: '/admin/tenant',
            name: '运营商管理',
            icon: <AuditOutlined />,
          },
          {
            path: '/admin/station',
            name: '电站管理',
            icon: <ThunderboltOutlined />,
          },
        ],
      },
      {
        path: '/system',
        name: '系统管理',
        icon: <ToolOutlined />,
        children: [
          {
            path: '/system/account',
            name: '我的账号',
            icon: <UserOutlined />,
          },
          {
            path: '/system/user',
            name: '用户管理',
            icon: <TeamOutlined />,
            hideInMenu: !access.canCommon,
          },
          {
            path: '/system/setting',
            name: '系统设置',
            icon: <SettingOutlined />,
            hideInMenu: !access.canAdmin,
          },
          {
            path: '/system/dict',
            name: '数据字典',
            icon: <CarryOutOutlined />,
            hideInMenu: !access.canRoot,
          },
        ],
      },
    ];
    setMenu(menus);
  }, [
    access.canRoot,
    access.canAdmin,
    access.canOperator,
    access.canStation,
    access.canCustomer,
    access.canDriver,
    access.canCommon,
    access.canDashboard,
  ]);

  const logo = <Action tools={[<ActionHome key="ActionHome" />]} />;

  const leftHeaderRender = () => {
    return <Action tools={[<LinkGoohier key="LinkGoohier" showName jumpWeb />]} />;
  };

  const rightHeaderRender = () => {
    return (
      <Action tools={[<ThemeStyle key="ThemeStyle" />, <MenuUser key="MenuUser" showName />]} />
    );
  };

  const menuItemRender = (item: any, defaultDom: any) => {
    return <div onClick={() => history.push(item.path)}>{defaultDom}</div>;
  };

  return (
    <ProLayout
      location={location}
      layout="mix"
      splitMenus
      navTheme="light"
      headerTheme="light"
      headerHeight={56}
      siderWidth={240}
      fixedHeader
      fixSiderbar
      logo={logo}
      title={false}
      headerTitleRender={() => leftHeaderRender()}
      rightContentRender={() => rightHeaderRender()}
      menuDataRender={() => menu}
      menuItemRender={(item: any, defaultDom: any) => menuItemRender(item, defaultDom)}
    >
      <Outlet />
    </ProLayout>
  );
};

export default BaseLayout;
