import { useDictSelect } from '@/utils/dict';
import { Form, Input, Modal, Select } from 'antd';
import _ from 'lodash';
import { useEffect, useState } from 'react';
import { deviceAddService, deviceListService } from './service';

const DialogAdd = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await deviceAddService(params);
    if (result?.success) onOk();
  };

  const [list, setList] = useState<any>([]);
  useEffect(() => {
    deviceListService({ tid: current?.tid }).then((result) => setList(result?.data));
  }, [current?.tid]);

  const isEqual = (params: any) =>
    list.some((item: any) => _.isEqual(params, _.pick(item, Object.keys(params))));

  const validator = async (rule: any, value: any) => {
    if (value?.length > 0 && isEqual({ [rule.field]: value })) {
      throw new Error('该编号已存在');
    }
  };

  const deviceTypeSelect = useDictSelect('device.type');
  const deviceStatusSelect = useDictSelect('device.status');

  return (
    <Modal destroyOnClose title="添加设备" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="设备编号"
          name="code"
          rules={[{ required: true, message: '设备编号必填' }, { validator }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="设备类型"
          name="type"
          rules={[{ required: true, message: '设备类型必选' }]}
        >
          <Select placeholder="请选择" allowClear options={deviceTypeSelect} />
        </Form.Item>
        <Form.Item
          label="设备状态"
          name="status"
          rules={[{ required: true, message: '设备状态必选' }]}
        >
          <Select placeholder="请选择" allowClear options={deviceStatusSelect} />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogAdd;
