import { useDictSelect } from '@/utils/dict';
import { Form, Input, Modal, Select } from 'antd';
import { deviceEditService } from './service';

const DialogEdit = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await deviceEditService(params);
    if (result?.success) onOk();
  };

  const deviceTypeSelect = useDictSelect('device.type');
  const deviceStatusSelect = useDictSelect('device.status');

  return (
    <Modal destroyOnClose title="编辑设备" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="设备编号"
          name="code"
          rules={[{ required: true, message: '设备编号必填' }]}
        >
          <Input placeholder="请输入" disabled />
        </Form.Item>
        <Form.Item
          label="设备类型"
          name="type"
          rules={[{ required: true, message: '设备类型必选' }]}
        >
          <Select placeholder="请选择" allowClear options={deviceTypeSelect} />
        </Form.Item>
        <Form.Item
          label="设备状态"
          name="status"
          rules={[{ required: true, message: '设备状态必选' }]}
        >
          <Select placeholder="请选择" allowClear options={deviceStatusSelect} />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogEdit;
