import { useDictSelect } from '@/utils/dict';
import { DeleteOutlined, EditOutlined, PlusOutlined } from '@ant-design/icons';
import { PageContainer, ProDescriptions } from '@ant-design/pro-components';
import { Button, Card, List, Modal } from 'antd';
import { useEffect, useState } from 'react';
import { useParams } from 'umi';
import { stationIdService } from '../Station/service';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { deviceListService, deviceRemoveService } from './service';

const Page = () => {
  const { id } = useParams<any>();

  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const [loading, setLoading] = useState(true);
  const [refresh, setRefresh] = useState(true);
  const [list, setList] = useState<any>([]);
  const [detail, setDetail] = useState<any>();

  useEffect(() => {
    const fetchData = async () => {
      setLoading(true);
      if (id) {
        const result1 = await stationIdService({ id });
        setDetail(result1?.data);

        const result2 = await deviceListService({ sid: result1?.data?.id, tid: result1?.data?.tid });
        setList(result2?.data);
      }
      setLoading(false);
    };
    fetchData();
  }, [id, refresh]);

  const deviceTypeSelect = useDictSelect('device.type');
  const deviceStatusSelect = useDictSelect('device.status');

  return (
    <PageContainer
      loading={loading}
      breadcrumbRender={false}
      title="电站详情"
      onBack={() => window.history.back()}
      content={
        <ProDescriptions column={3}>
          <ProDescriptions.Item label="电站编号">{detail?.code}</ProDescriptions.Item>
          <ProDescriptions.Item label="电站名称">{detail?.name}</ProDescriptions.Item>
          <ProDescriptions.Item label="电站地址">{detail?.address}</ProDescriptions.Item>
          <ProDescriptions.Item label="电站位置">{detail?.location}</ProDescriptions.Item>
          <ProDescriptions.Item label="创建时间" valueType="dateTime">
            {detail?.createAt}
          </ProDescriptions.Item>
          <ProDescriptions.Item label="更新时间" valueType="dateTime">
            {detail?.updateAt}
          </ProDescriptions.Item>
        </ProDescriptions>
      }
      extra={
        <Button
          key="add"
          type="primary"
          onClick={() => {
            setCurrent({ sid: detail?.id, tid: detail?.tid });
            setVisibleAdd(true);
          }}
        >
          <PlusOutlined /> 添加设备
        </Button>
      }
    >
      <List
        loading={loading}
        grid={{
          gutter: 16,
          xs: 1,
          sm: 2,
          md: 2,
          lg: 2,
          xl: 3,
          xxl: 4,
        }}
        dataSource={list}
        renderItem={(item: any) => (
          <List.Item>
            <Card
              title={`设备编号：${item?.code}`}
              actions={[
                <a
                  key="edit"
                  onClick={() => {
                    setCurrent(item);
                    setVisibleEdit(true);
                  }}
                >
                  <EditOutlined />
                </a>,
                <a
                  key="remove"
                  onClick={() => {
                    Modal.confirm({
                      title: '确定删除该项吗？',
                      okType: 'danger',
                      onOk: async () => {
                        await deviceRemoveService(item);
                        setRefresh(!refresh);
                      },
                    });
                  }}
                >
                  <DeleteOutlined />
                </a>,
              ]}
            >
              <ProDescriptions column={1}>
                <ProDescriptions.Item label="设备类型">
                  {deviceTypeSelect.find((type: any) => type?.value === item?.type)?.label}
                </ProDescriptions.Item>
                <ProDescriptions.Item label="设备状态">
                  {deviceStatusSelect.find((status: any) => status?.value === item?.status)?.label}
                </ProDescriptions.Item>
              </ProDescriptions>
            </Card>
          </List.Item>
        )}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            setRefresh(!refresh);
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            setRefresh(!refresh);
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
