import { Form, Input, Modal, Select } from 'antd';
import { useEffect, useState } from 'react';
import { tenantListService } from '../Tenant/service';
import { stationEditService } from './service';

const DialogEdit = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await stationEditService(params);
    if (result?.success) onOk();
  };

  const [tenant, setTenant] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await tenantListService({});
      if (result?.data) setTenant(result?.data);
    };
    fetchData();
  }, []);

  return (
    <Modal destroyOnClose title="编辑电站" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="所属运营商"
          name="tid"
          rules={[{ required: true, message: '所属运营商必填' }]}
        >
          <Select
            placeholder="请选择"
            allowClear
            options={tenant.map((item: any) => {
              return { label: item?.name, value: item?.id };
            })}
            disabled
          />
        </Form.Item>
        <Form.Item
          label="电站名称"
          name="name"
          rules={[{ required: true, message: '电站名称必填' }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="电站地址"
          name="address"
          rules={[{ required: true, message: '电站地址必填' }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="电站位置"
          name="location"
          rules={[{ required: true, message: '电站位置必填' }]}
          tooltip={
            <a
              href="https://api.map.baidu.com/lbsapi/getpoint/index.html"
              target="_blank"
              rel="noreferrer"
            >
              点击此处，地图上找经纬度坐标
            </a>
          }
        >
          <Input placeholder="经纬度坐标" allowClear />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogEdit;
