import { useDictEnum } from '@/utils/dict';
import { PlusOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Link } from '@umijs/max';
import { Button, Modal } from 'antd';
import { useEffect, useRef, useState } from 'react';
import { tenantListService } from '../Tenant/service';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { stationPageService, stationRemoveService } from './service';

const Page = () => {
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const systemStatusEnum = useDictEnum('system.status');

  const [tenant, setTenant] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await tenantListService({});
      if (result?.data) setTenant(result?.data);
    };
    fetchData();
  }, []);

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '电站名称',
      dataIndex: 'name',
      render: (text: any, record: any) => <Link to={`./${record.id}`}>{text}</Link>,
      width: 200,
    },
    {
      title: '电站地址',
      dataIndex: 'address',
      hideInSearch: true,
      width: 600,
    },
    {
      title: '电站位置',
      dataIndex: 'location',
      tooltip: '电站的经纬度坐标',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '运营商',
      dataIndex: 'tid',
      valueType: 'select',
      fieldProps: {
        options: tenant.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '排队数量',
      dataIndex: 'wait',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: systemStatusEnum,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 200,
      render: (_text: any, record: any) => [
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项吗？',
              okType: 'danger',
              onOk: async () => {
                await stationRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="电站列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({});
              setVisibleAdd(true);
            }}
          >
            <PlusOutlined /> 添加
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await stationPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
