import { Form, Input, Modal } from 'antd';
import { tenantEditService } from './service';

const DialogEdit = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await tenantEditService(params);
    if (result?.success) onOk();
  };

  return (
    <Modal destroyOnClose title="编辑运营商" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="运营商名称"
          name="name"
          rules={[{ required: true, message: '运营商名称必填' }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="联系人"
          name="contact"
          rules={[{ required: true, message: '联系人必填' }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="联系手机"
          name="phone"
          rules={[
            { required: true, message: '联系手机必填' },
            { pattern: /^1\d{10}$/, message: '手机格式错误' },
          ]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogEdit;
