import { PlusOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button, Modal } from 'antd';
import { useRef, useState } from 'react';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { tenantPageService, tenantRemoveService } from './service';

const Page = () => {
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '运营商名称',
      dataIndex: 'name',
      width: 200,
    },
    {
      title: '联系人',
      dataIndex: 'contact',
      width: 200,
    },
    {
      title: '联系手机',
      dataIndex: 'phone',
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 200,
      render: (_text: any, record: any) => [
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项吗？',
              okType: 'danger',
              onOk: async () => {
                await tenantRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="运营商列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({});
              setVisibleAdd(true);
            }}
          >
            <PlusOutlined /> 添加
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await tenantPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
