import { batteryPageService } from '@/pages/operator/Battery/service';
import { vehicleListService } from '@/pages/operator/Vehicle/service';
import { stationListService } from '@/pages/admin/Station/service';
import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { useRef, useState, useEffect } from 'react';

const Page = () => {
  const { account } = useAccount();

  const [vehicles, setVehicles] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await vehicleListService({ tid: account?.tid });
      if (result?.data) setVehicles(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await stationListService({ tid: account?.tid });
      if (result?.data) setStations(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const batteryPlaceEnum = useDictEnum('battery.place');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '电池编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '电池电量',
      dataIndex: 'level',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '电池放置',
      dataIndex: 'place',
      valueType: 'select',
      valueEnum: batteryPlaceEnum,
      width: 200,
    },
    {
      title: '所在车辆',
      dataIndex: 'vid',
      valueType: 'select',
      fieldProps: {
        options: vehicles.map((item: any) => {
          return { label: item?.code, value: item?.id };
        }),
      },
      hideInSearch: true,
      width: 200,
    },
    {
      title: '所在电站',
      dataIndex: 'sid',
      valueType: 'select',
      fieldProps: {
        options: stations.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      hideInSearch: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="电池列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await batteryPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ cid: account?.cid, tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
