import { billPageService } from '@/pages/operator/Bill/service';
import { customerIdService } from '@/pages/operator/Customer/service';
import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { useEffect, useRef, useState } from 'react';

const Page = () => {
  const { account } = useAccount();

  const [customer, setCustomer] = useState<any>();
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerIdService({ id: account?.cid, tid: account?.tid });
      if (result?.data) setCustomer(result?.data);
    };
    fetchData();
  }, [account?.cid, account?.tid]);

  const paymentTypeEnum = useDictEnum('payment.type');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '类型',
      dataIndex: 'type',
      valueType: 'select',
      valueEnum: paymentTypeEnum,
      filters: true,
      onFilter: true,
      width: 200,
    },
    {
      title: '客户',
      dataIndex: 'name',
      render: () => <div>{customer?.name}</div>,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '账户余额',
      dataIndex: 'amount',
      valueType: 'digit',
      render: () => <div>{customer?.amount}</div>,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '本次金额',
      dataIndex: 'cost',
      valueType: 'digit',
      sorter: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="费用列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await billPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ cid: account?.cid, tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
