import { vehicleListService } from '@/pages/operator/Vehicle/service';
import { userPageService } from '@/pages/system/User/service';
import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { useEffect, useRef, useState } from 'react';

const Page = () => {
  const { account } = useAccount();

  const [vehicles, setVehicles] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await vehicleListService({ cid: account?.cid, tid: account?.tid });
      if (result?.data) setVehicles(result?.data);
    };
    fetchData();
  }, [account?.cid, , account?.tid]);

  const systemStatusEnum = useDictEnum('system.status');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '账号',
      dataIndex: 'username',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '手机',
      dataIndex: 'phone',
      width: 200,
    },
    {
      title: '姓名',
      dataIndex: 'name',
      width: 200,
    },
    {
      title: '绑定车辆',
      dataIndex: 'vid',
      valueType: 'select',
      fieldProps: {
        options: vehicles.map((item: any) => {
          return { label: item?.code, value: item?.id };
        }),
      },
      hideInSearch: true,
      width: 200,
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: systemStatusEnum,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="司机列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await userPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ role: 'driver', cid: account?.cid, tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
