import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { useEffect, useRef, useState } from 'react';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { orderPageService } from '@/pages/operator/Order/service';
import { customerListService } from '@/pages/operator/Customer/service';
import { stationListService } from '@/pages/admin/Station/service';

const Page = () => {
  const { account } = useAccount();

  const [customers, setCustomers] = useState<any>([]);
  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result1 = await customerListService({ tid: account?.tid });
      if (result1?.data) setCustomers(result1?.data);
      const result2 = await stationListService({ tid: account?.tid });
      if (result2?.data) setStations(result2?.data);
    };
    fetchData();
  }, [account?.tid]);

  const orderTypeEnum = useDictEnum('order.type');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '类型',
      dataIndex: 'type',
      valueType: 'select',
      valueEnum: orderTypeEnum,
      filters: true,
      onFilter: true,
      width: 200,
    },
    {
      title: '客户',
      dataIndex: 'cid',
      valueType: 'select',
      fieldProps: {
        options: customers.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      hideInSearch: true,
      width: 200,
    },
    {
      title: '电站',
      dataIndex: 'sid',
      valueType: 'select',
      fieldProps: {
        options: stations.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '车辆编号',
      dataIndex: 'vehicleCode',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '设备编号',
      dataIndex: 'deviceCode',
      tooltip: '换电=换电机器人编号，充电=充电桩编号',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '电量',
      dataIndex: 'level',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '费用',
      dataIndex: 'cost',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="订单列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await orderPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ cid: account?.cid, tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
