import { getThemeStyle } from '@/utils/preference';
import { Column, Area, Bar } from '@ant-design/charts';
import { ProCard, StatisticCard } from '@ant-design/pro-components';
import { Col, Row } from 'antd';
import { useEffect, useState } from 'react';
import { adminBasicService } from './service';

const AdminBasic = ({ height, refresh }: any) => {
  const [data, setData] = useState<any[]>([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await adminBasicService({});
      setData(result);
    };
    fetchData();
  }, [refresh]);

  return (
    <ProCard
      title={<span style={{ fontSize: 18, fontWeight: 'bolder' }}>综合统计</span>}
      style={{ height }}
    >
      <Row gutter={[8, 8]}>
        <Col span={12}>
          <div style={{ marginTop: -24, marginBottom: -16 }}>
            <StatisticCard
              statistic={{
                title: '累计电量',
                value: data?.find((item: any) => item?.type === 'level')?.value,
                precision: 0,
                suffix: '度',
              }}
            />
          </div>
          <div style={{ height: 80, padding: 8 }}>
            <Column
              theme={getThemeStyle()}
              xField="date"
              yField="value"
              yAxis={{
                label: null,
              }}
              meta={{
                value: {
                  alias: '电量',
                },
              }}
              data={[
                {
                  date: '2020',
                  value: 0,
                },
                {
                  date: '2021',
                  value: Math.trunc(data?.find((item: any) => item?.type === 'level')?.value / 5),
                },
                {
                  date: '2022',
                  value: data?.find((item: any) => item?.type === 'level')?.value,
                },
              ]}
            />
          </div>
        </Col>
        <Col span={12}>
          <div style={{ marginTop: -24, marginBottom: -16 }}>
            <StatisticCard
              statistic={{
                title: '累计金额',
                value: data?.find((item: any) => item?.type === 'cost')?.value,
                precision: 0,
                suffix: '元',
              }}
            />
          </div>
          <div style={{ height: 80, padding: 8 }}>
            <Area
              theme={getThemeStyle()}
              xField="date"
              yField="value"
              yAxis={{
                label: null,
              }}
              meta={{
                value: {
                  alias: '金额',
                },
              }}
              data={[
                {
                  date: '2020',
                  value: 0,
                },
                {
                  date: '2021',
                  value: Math.trunc(data?.find((item: any) => item?.type === 'cost')?.value / 5),
                },
                {
                  date: '2022',
                  value: Math.trunc(data?.find((item: any) => item?.type === 'cost')?.value),
                },
              ]}
            />
          </div>
        </Col>
        <Col span={12}>
          <div style={{ marginBottom: -16 }}>
            <StatisticCard
              statistic={{
                title: '累计车次',
                value: data?.find((item: any) => item?.type === 'count')?.value,
                precision: 0,
                suffix: '次',
              }}
            />
          </div>
          <div style={{ height: 80, padding: 8 }}>
            <Area
              theme={getThemeStyle()}
              xField="date"
              yField="value"
              yAxis={{
                label: null,
              }}
              meta={{
                value: {
                  alias: '车次',
                },
              }}
              data={[
                {
                  date: '2020',
                  value: 0,
                },
                {
                  date: '2021',
                  value: Math.trunc(data?.find((item: any) => item?.type === 'count')?.value / 5),
                },
                {
                  date: '2022',
                  value: data?.find((item: any) => item?.type === 'count')?.value,
                },
              ]}
            />
          </div>
        </Col>
        <Col span={12}>
          <div style={{ marginBottom: -16 }}>
            <StatisticCard
              statistic={{
                title: '电站总数',
                value: data?.find((item: any) => item?.type === 'station')?.value,
                precision: 0,
                suffix: '个',
              }}
            />
          </div>
          <div style={{ height: 80, padding: 8 }}>
            <Bar
              theme={getThemeStyle()}
              xField="value"
              yField="date"
              xAxis={{
                label: null,
              }}
              meta={{
                value: {
                  alias: '电站',
                },
              }}
              data={[
                {
                  date: '2022',
                  value: data?.find((item: any) => item?.type === 'station')?.value,
                },
                {
                  date: '2021',
                  value: Math.trunc(data?.find((item: any) => item?.type === 'station')?.value / 5),
                },
                {
                  date: '2020',
                  value: 0,
                },
              ]}
            />
          </div>
        </Col>
      </Row>
    </ProCard>
  );
};

export default AdminBasic;
