import { Pie, Liquid } from '@ant-design/charts';
import { ProCard, StatisticCard } from '@ant-design/pro-components';
import { useEffect, useState } from 'react';
import {
  adminFooterChargeService,
  adminFooterPowerService,
  adminFooterTotalService,
} from './service';
import { getThemeStyle } from '@/utils/preference';
import { Col, Row } from 'antd';

const AdminFooter = ({ height, refresh }: any) => {
  const [total, setTotal] = useState(0);
  const [power, setPower] = useState([]);
  const [charge, setCharge] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result1 = await adminFooterTotalService({});
      setTotal(result1);
      const result2 = await adminFooterPowerService({});
      setPower(result2);
      const result3 = await adminFooterChargeService({});
      setCharge(result3);
    };
    fetchData();
  }, [refresh]);

  const configLiquid: any = {
    theme: getThemeStyle(),
    outline: {
      border: 2,
      distance: 3,
    },
    wave: {
      length: 100,
    },
  };

  const configPie: any = {
    theme: getThemeStyle(),
    angleField: 'value',
    colorField: 'name',
    radius: 0.7,
    label: {
      style: {
        fontSize: 20,
      },
    },
    legend: false,
  };

  return (
    <Row gutter={[8, 8]}>
      <Col span={14}>
        <ProCard style={{ height }}>
          <Row gutter={[8, 0]}>
            <Col span={8}>
              <div style={{ textAlign: 'center', marginTop: -24, marginBottom: -16 }}>
                <StatisticCard
                  statistic={{
                    title: '峰电电量',
                    value: total * 0.292,
                    precision: 0,
                  }}
                />
              </div>
              <div style={{ height: height - 110 }}>
                <Liquid {...configLiquid} percent={0.292} />
              </div>
            </Col>
            <Col span={8}>
              <div style={{ textAlign: 'center', marginTop: -24, marginBottom: -16 }}>
                <StatisticCard
                  statistic={{
                    title: '谷电电量',
                    value: total * 0.331,
                    precision: 0,
                  }}
                />
              </div>
              <div style={{ height: height - 110 }}>
                <Liquid {...configLiquid} percent={0.331} />
              </div>
            </Col>
            <Col span={8}>
              <div style={{ textAlign: 'center', marginTop: -24, marginBottom: -16 }}>
                <StatisticCard
                  statistic={{
                    title: '平电电量',
                    value: total * 0.377,
                    precision: 0,
                  }}
                />
              </div>
              <div style={{ height: height - 110 }}>
                <Liquid {...configLiquid} percent={0.377} />
              </div>
            </Col>
          </Row>
        </ProCard>
      </Col>
      <Col span={10}>
        <ProCard style={{ height }}>
          <Row gutter={[8, 0]}>
            <Col span={12}>
              <div style={{ textAlign: 'center', marginTop: -8, marginBottom: 8, fontSize: 16 }}>
                充电机组实时状态
              </div>
              <div style={{ height: height - 60 }}>
                <Pie {...configPie} data={power} />
              </div>
            </Col>
            <Col span={12}>
              <div style={{ textAlign: 'center', marginTop: -8, marginBottom: 8, fontSize: 16 }}>
                充电桩实时状态
              </div>
              <div style={{ height: height - 60 }}>
                <Pie {...configPie} data={charge} />
              </div>
            </Col>
          </Row>
        </ProCard>
      </Col>
    </Row>
  );
};

export default AdminFooter;
