import { Area } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { adminFrequencyService } from './service';
import { getThemeStyle } from '@/utils/preference';

const AdminFrequency = ({ height, refresh }: any) => {
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await adminFrequencyService({ date });
      setData(result);
    };
    fetchData();
  }, [date, refresh]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'date',
    yField: 'value',
    meta: {
      name: {
        alias: '周期',
      },
      value: {
        alias: '次数',
      },
    },
  };

  return (
    <ProCard
      title={<span style={{ fontSize: 18, fontWeight: 'bolder' }}>充电和换电总次数</span>}
      style={{ height }}
      extra={
        <DatePicker
          picker="month"
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString + '-01')}
        />
      }
    >
      <Area {...config} />
    </ProCard>
  );
};

export default AdminFrequency;
