import { DotMap, registerImages } from '@ant-design/charts';
import { useEffect, useState } from 'react';
import { adminMapService } from './service';
import { getThemeStyle } from '@/utils/preference';
import { ProCard } from '@ant-design/pro-components';

const AdminMap = ({ height, refresh }: any) => {
  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await adminMapService({});
      setData(result);
    };
    fetchData();
  }, [refresh]);

  const images = [
    {
      id: 'station',
      image: '/station.png',
    },
    {
      id: 'vehicle',
      image: '/vehicle.png',
    },
  ];
  registerImages(images);

  const config: any = {
    theme: getThemeStyle() === 'dark' ? 'dark' : 'light',
    map: {
      type: 'amap',
      // center: [120.338723, 31.914388],
      zoom: 10,
      pitch: 0,
    },
    autoFit: true,
    source: {
      data: data,
      parser: {
        type: 'json',
        x: 'longitude',
        y: 'latitude',
      },
    },
    style: {
      opacity: 1,
      strokeWidth: 0,
    },
    state: {
      active: true,
    },
    color: '#ffffff',
    label: {
      visible: false,
    },
    size: {
      field: 'type',
      value: ({ type }: any) => {
        return type === 'station' ? 32 : 16;
      },
    },
    animate: true,
    shape: {
      field: 'type',
      value: ['station', 'vehicle'],
    },
    tooltip: {
      items: [
        {
          field: 'code',
          alias: '车辆',
        },
        {
          field: 'name',
          alias: '名称',
        },
        {
          field: 'address',
          alias: '地址',
        },
        {
          field: 'tenant',
          alias: '运营商',
        },
      ],
    },
  };

  return (
    <ProCard style={{ height }} ghost>
      <DotMap {...config} />
    </ProCard>
  );
};

export default AdminMap;
