import { ShowDateTime } from '@/components/Action/ShowDateTime';
import { FullscreenExitOutlined, FullscreenOutlined, ReloadOutlined } from '@ant-design/icons';
import { Col, Row, Space, Tooltip, Typography } from 'antd';
import { useRef, useState } from 'react';
import AdminAbnormal from './AdminAbnormal';
import AdminBasic from './AdminBasic';
import AdminContrast from './AdminContrast';
import AdminFrequency from './AdminFrequency';
import AdminLevel from './AdminLevel';
import AdminVehicle from './AdminVehicle';
import AdminMap from './AdminMap';
import AdminHeader from './AdminHeader';
import AdminFooter from './AdminFooter';

const Page = () => {
  const ref = useRef<any>();
  const [fullscreen, setFullscreen] = useState(document.fullscreenElement !== null);
  const onFullscreen = () => {
    if (document.fullscreenElement !== null) {
      setFullscreen(false);
      document.exitFullscreen();
    } else {
      setFullscreen(true);
      ref.current.requestFullscreen();
    }
  };

  const [refresh, setRefresh] = useState(false);
  const onRefresh = () => {
    setRefresh(!refresh);
  };

  const height = window.innerHeight;
  // const [height, setHeight] = useState(window.innerHeight);
  // window.onresize = () => {
  //   setHeight(window.innerHeight);
  // };

  const getCurrentHeight = () => {
    if (fullscreen) return height - 80 - 16;
    return height - 56 - 48 - 80;
  };

  const getHeight = () => {
    if (getCurrentHeight() < 984) return 984;
    return getCurrentHeight();
  };

  const getHeightLeftTop = () => {
    return 440;
  };

  const getHeightLeft = () => {
    return (getHeight() - 16 - getHeightLeftTop()) / 2;
  };

  const getHeightCenterTop = () => {
    return 120;
  };

  const getHeightCenterBottom = () => {
    return 240;
  };

  const getHeightCenter = () => {
    return getHeight() - 16 - getHeightCenterTop() - getHeightCenterBottom();
  };

  const getHeightRightBottom = () => {
    return 320;
  };

  const getHeightRight = () => {
    return (getHeight() - 16 - getHeightRightBottom()) / 2;
  };

  return (
    <div ref={ref} style={{ backgroundColor: '#f0f2f5', padding: fullscreen ? 8 : 0 }}>
      <div style={{ backgroundColor: '#fff', padding: '8px 24px', height: 64, marginBottom: 12 }}>
        <Row>
          <Col span={8}>
            <div style={{ display: 'flex', justifyContent: 'left', paddingTop: 12 }}>
              <Typography.Title level={4}>
                <ShowDateTime />
              </Typography.Title>
            </div>
          </Col>
          <Col span={8}>
            <div style={{ display: 'flex', justifyContent: 'center', paddingTop: 8 }}>
              <Typography.Title level={3} type="success">
                国海智云
              </Typography.Title>
            </div>
          </Col>
          <Col span={8}>
            <div style={{ display: 'flex', justifyContent: 'right', paddingTop: 16 }}>
              <Space size="large">
                <Tooltip title="刷新">
                  <a onClick={onRefresh}>
                    <ReloadOutlined style={{ fontSize: 18 }} />
                  </a>
                </Tooltip>
                {fullscreen ? (
                  <Tooltip title="退出全屏">
                    <a onClick={onFullscreen}>
                      <FullscreenExitOutlined style={{ fontSize: 18 }} />
                    </a>
                  </Tooltip>
                ) : (
                  <Tooltip title="全屏">
                    <a onClick={onFullscreen}>
                      <FullscreenOutlined style={{ fontSize: 18 }} />
                    </a>
                  </Tooltip>
                )}
              </Space>
            </div>
          </Col>
        </Row>
      </div>
      <Row gutter={[8, 8]}>
        <Col span={6}>
          <Row gutter={[8, 8]}>
            <Col span={24}>
              <AdminBasic height={getHeightLeftTop()} refresh={refresh} />
            </Col>
            <Col span={24}>
              <AdminAbnormal height={getHeightLeft()} refresh={refresh} />
            </Col>
            <Col span={24}>
              <AdminVehicle height={getHeightLeft()} refresh={refresh} />
            </Col>
          </Row>
        </Col>
        <Col span={12}>
          <Row gutter={[8, 8]}>
            <Col span={24}>
              <AdminHeader height={getHeightCenterTop()} refresh={refresh} />
            </Col>
            <Col span={24}>
              <AdminMap height={getHeightCenter()} refresh={refresh} />
            </Col>
            <Col span={24}>
              <AdminFooter height={getHeightCenterBottom()} refresh={refresh} />
            </Col>
          </Row>
        </Col>
        <Col span={6}>
          <Row gutter={[8, 8]}>
            <Col span={24}>
              <AdminContrast height={getHeightRight()} refresh={refresh} />
            </Col>
            <Col span={24}>
              <AdminFrequency height={getHeightRight()} refresh={refresh} />
            </Col>
            <Col span={24}>
              <AdminLevel height={getHeightRightBottom()} refresh={refresh} />
            </Col>
          </Row>
        </Col>
      </Row>
    </div>
  );
};

export default Page;
