import { useAccount } from '@/utils/hooks';
import { DatePicker } from 'antd';
import { ProCard, StatisticCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { customerAmountService } from './service';

const CustomerAmount = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState<any[]>([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await customerAmountService({ tid: account?.tid, cid: account?.cid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.cid, date]);

  return (
    <ProCard
      title="综合统计"
      style={{ height }}
      extra={
        <DatePicker
          showTime
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <StatisticCard.Group>
        <StatisticCard
          statistic={{
            tip: '如果是负值，表明出现欠款。',
            title: '账户余额',
            value: data?.find((item: any) => item?.type === 'amount')?.value,
            suffix: '元',
          }}
        />
        <StatisticCard
          statistic={{
            title: '累计金融',
            value: data?.find((item: any) => item?.type === 'cost')?.value,
            suffix: '元',
          }}
        />
      </StatisticCard.Group>
      <StatisticCard.Group>
        <StatisticCard
          statistic={{
            title: '换电次数',
            value: data?.find((item: any) => item?.type === 'count')?.value,
            suffix: '次',
          }}
        />
        <StatisticCard
          statistic={{
            title: '累计电量',
            value: data?.find((item: any) => item?.type === 'level')?.value,
            suffix: '度',
          }}
        />
      </StatisticCard.Group>
    </ProCard>
  );
};

export default CustomerAmount;
