import { useAccount } from '@/utils/hooks';
import { DualAxes } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { customerDailyService } from './service';
import { getThemeStyle } from '@/utils/preference';

const CustomerDaily = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await customerDailyService({ tid: account?.tid, cid: account?.cid, date });

      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.cid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data: [data, data],
    xField: 'date',
    yField: ['value', 'price'],
    meta: {
      value: {
        alias: '每日电量',
      },
      price: {
        alias: '每日金额',
        min: 0,
      },
    },
    legend: {
      position: 'bottom',
    },
    geometryOptions: [
      {
        geometry: 'column',
        label: {
          position: 'middle',
        },
      },
      {
        geometry: 'line',
        label: {
          position: 'middle',
        },
      },
    ],
  };

  return (
    <ProCard
      title="近一月电量（度）与金额（元）"
      style={{ height }}
      extra={
        <DatePicker
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <DualAxes {...config} />
    </ProCard>
  );
};

export default CustomerDaily;
