import { useAccount } from '@/utils/hooks';
import { Column } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { customerExtremumService } from './service';
import { getThemeStyle } from '@/utils/preference';

const CustomerExtremum = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await customerExtremumService({ tid: account?.tid, cid: account?.cid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.cid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'name',
    yField: 'value',
    seriesField: 'type',
    legend: {
      position: 'bottom',
    },
    label: {
      position: 'middle',
    },
    meta: {
      name: {
        alias: '车辆编号',
      },
      value: {
        alias: '换电电量',
      },
    },
  };

  return (
    <ProCard
      title="近一月前三名和后三名车辆换电电量（度）"
      style={{ height }}
      extra={
        <DatePicker
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <Column {...config} />
    </ProCard>
  );
};

export default CustomerExtremum;
