import { Line } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { getThemeStyle } from '@/utils/preference';
import { customerGradientService, customerRuleService } from './service';

const CustomerGradient = ({ tid, cid, name, height }: any) => {
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);
  const [rule, setRule] = useState(0);
  const [max, setMax] = useState(0);

  useEffect(() => {
    const fetchData = async () => {
      const list = await customerGradientService({ tid: tid, cid: cid, date });
      setData(list);
      const gradient = await customerRuleService({ tid: tid, cid: cid });
      setRule(gradient);
      const accArray = list?.map((item: any) => item.acc);
      const maxAcc = Math.max(...accArray);
      setMax(gradient > maxAcc ? gradient : maxAcc);
    };
    fetchData();
  }, [tid, cid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'date',
    yField: 'acc',
    stepType: 'vh',
    meta: {
      date: {
        alias: '累计周期',
      },
      acc: {
        alias: '累计电量',
        min: 0,
        max: max * 1.1,
      },
    },
    label: {
      position: 'middle',
      offsetX: 20,
      offsetY: 10,
    },
    annotations: [
      {
        type: 'line',
        start: ['min', rule],
        end: ['max', rule],
        style: {
          lineWidth: 2,
          stroke: '#ff4500',
        },
      },
      {
        type: 'text',
        position: ['min', rule],
        content: `年电量梯度线：${rule}`,
        offsetY: -4,
        style: {
          textBaseline: 'bottom',
        },
      },
    ],
  };

  return (
    <ProCard
      title={`${name}近一年电量累计（度）和电量梯度线（度）`}
      style={{ height }}
      extra={
        <DatePicker
          picker="month"
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString + '-01')}
        />
      }
    >
      <Line {...config} />
    </ProCard>
  );
};

export default CustomerGradient;
