import { useAccount } from '@/utils/hooks';
import { Line } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { operatoPriceService } from './service';
import { getThemeStyle } from '@/utils/preference';

const OperatorPrice = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await operatoPriceService({ tid: account?.tid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'date',
    yField: 'value',
    meta: {
      date: {
        alias: '周期',
      },
      value: {
        alias: '单价',
      },
    },
    label: {
      position: 'middle',
    },
    annotations: [
      {
        type: 'line',
        start: ['min', 'median'],
        end: ['max', 'median'],
        style: {
          stroke: '#ff4500',
          lineDash: [2, 2],
        },
      },
      {
        type: 'text',
        position: ['min', 'median'],
        content: '中位数',
        offsetY: -4,
        style: {
          textBaseline: 'bottom',
        },
      },
    ],
  };

  return (
    <ProCard
      title="近一年电网电价波动（元/度）"
      style={{ height }}
      extra={
        <DatePicker
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <Line {...config} />
    </ProCard>
  );
};

export default OperatorPrice;
