import { useAccount } from '@/utils/hooks';
import { Column } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { operatorVehicleService } from './service';
import { getThemeStyle } from '@/utils/preference';

const OperatorVehicle = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await operatorVehicleService({ tid: account?.tid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'date',
    yField: 'value',
    seriesField: 'name',
    isGroup: true,
    legend: {
      position: 'bottom',
    },
    label: {
      position: 'middle',
    },
  };

  return (
    <ProCard
      title="近一年客户车辆数量变化"
      style={{ height }}
      extra={
        <DatePicker
          picker="month"
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString + '-01')}
        />
      }
    >
      <Column {...config} />
    </ProCard>
  );
};

export default OperatorVehicle;
