import { useAccount } from '@/utils/hooks';
import { useState, useEffect } from 'react';
import { Col, Divider, Row } from 'antd';
import OperatorAmount from './OperatorAmount';
import OperatorCustomerCost from './OperatorCustomerCost';
import OperatorCustomerLevel from './OperatorCustomerLevel';
import OperatorFault from './OperatorFault';
import OperatorPrice from './OperatorPrice';
import OperatorStationCost from './OperatorStationCost';
import OperatorStationLevel from './OperatorStationLevel';
import OperatorVehicle from './OperatorVehicle';
import { operatorCustomerListService } from './service';
import CustomerGradient from '../Customer/CustomerGradient';

const Page = () => {
  const { account } = useAccount();
  const [data, setData] = useState<any[]>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await operatorCustomerListService({ tid: account?.tid });
      setData(result);
    };
    fetchData();
  }, [account?.tid]);

  const [height, setHeight] = useState(window.innerHeight);

  window.onresize = () => {
    setHeight(window.innerHeight);
  };

  const getCurrentHeight = () => {
    return height - 56 - 48 - 32 < 1320 ? 1320 : height - 56 - 48 - 32;
  };

  const getHeight = () => {
    return getCurrentHeight() / 4;
  };

  return (
    <div>
      <Row gutter={[16, 16]}>
        <Col span={12}>
          <OperatorAmount height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorPrice height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorCustomerLevel height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorCustomerCost height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorStationLevel height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorStationCost height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorVehicle height={getHeight()} />
        </Col>
        <Col span={12}>
          <OperatorFault height={getHeight()} />
        </Col>
      </Row>
      {data?.length > 0 && (
        <div>
          <Divider />
          <Row gutter={[16, 16]}>
            {data?.map((item) => {
              return (
                <Col span={12} key={item?.cid}>
                  <CustomerGradient
                    tid={account?.tid}
                    cid={item?.cid}
                    name={item?.name}
                    height={getHeight()}
                  />
                </Col>
              );
            })}
          </Row>
        </div>
      )}
    </div>
  );
};

export default Page;
