import { useAccount } from '@/utils/hooks';
import { DatePicker } from 'antd';
import { ProCard, StatisticCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { stationAmountService } from './service';

const StationAmount = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState<any[]>([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await stationAmountService({ tid: account?.tid, sid: account?.sid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.sid, date]);

  return (
    <ProCard
      title="综合统计"
      style={{ height }}
      extra={
        <DatePicker
          showTime
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <StatisticCard.Group>
        <StatisticCard
          statistic={{
            tip: '电站识别到的车辆',
            title: '排队数量',
            value: data?.find((item: any) => item?.type === 'wait')?.value,
            suffix: '辆',
          }}
        />
        <StatisticCard
          statistic={{
            title: '累计金融',
            value: data?.find((item: any) => item?.type === 'cost')?.value,
            suffix: '元',
          }}
        />
      </StatisticCard.Group>
      <StatisticCard.Group>
        <StatisticCard
          statistic={{
            title: '换电次数',
            value: data?.find((item: any) => item?.type === 'count')?.value,
            suffix: '次',
          }}
        />
        <StatisticCard
          statistic={{
            title: '累计电量',
            value: data?.find((item: any) => item?.type === 'level')?.value,
            suffix: '度',
          }}
        />
      </StatisticCard.Group>
    </ProCard>
  );
};

export default StationAmount;
