import { useAccount } from '@/utils/hooks';
import { Pie } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { useEffect, useState } from 'react';
import { stationCumulativeService } from './service';
import { getThemeStyle } from '@/utils/preference';

const StationCumulative = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await stationCumulativeService({ tid: account?.tid, sid: account?.sid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.sid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    angleField: 'value',
    colorField: 'name',
    radius: 0.8,
    legend: {
      position: 'bottom',
    },
  };

  return (
    <ProCard
      title="近一年换电电量累计（度）"
      style={{ height }}
      extra={
        <DatePicker
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <Pie {...config} />
    </ProCard>
  );
};

export default StationCumulative;
