import { Bar } from '@ant-design/charts';
import { useEffect, useState } from 'react';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { stationPowerService } from './service';
import { useAccount } from '@/utils/hooks';
import { getThemeStyle } from '@/utils/preference';

const StationPower = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await stationPowerService({ tid: account?.tid, sid: account?.sid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.sid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'value',
    yField: 'code',
    seriesField: 'type',
    isStack: true,
    legend: {
      position: 'bottom',
    },
    label: {
      position: 'middle',
      content: (item: any) => {
        return item?.value === 0 ? '' : item.value;
      },
    },
  };

  return (
    <ProCard
      title="近一月充电机组工作状况（小时）"
      style={{ height }}
      extra={
        <DatePicker
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <Bar {...config} />
    </ProCard>
  );
};

export default StationPower;
