import { Column } from '@ant-design/charts';
import { useEffect, useState } from 'react';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { stationTimeService } from './service';
import { useAccount } from '@/utils/hooks';
import { getThemeStyle } from '@/utils/preference';

const StationTime = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await stationTimeService({ tid: account?.tid, sid: account?.sid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.sid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'date',
    yField: 'value',
    meta: {
      date: {
        alias: '时间',
      },
      value: {
        alias: '电量',
      },
    },
    label: {
      position: 'middle',
    },
  };

  return (
    <ProCard
      title="近一日换电电量（度）"
      style={{ height }}
      extra={
        <DatePicker
          showTime
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <Column {...config} />
    </ProCard>
  );
};

export default StationTime;
