import { useAccount } from '@/utils/hooks';
import { useState, useEffect } from 'react';
import { Line } from '@ant-design/charts';
import { DatePicker } from 'antd';
import { ProCard } from '@ant-design/pro-components';
import moment from 'moment';
import { stationTrendService } from './service';
import { getThemeStyle } from '@/utils/preference';

const StationTrend = ({ height }: any) => {
  const { account } = useAccount();
  const [date, setDate] = useState(moment().format('YYYY-MM-DD HH:mm:ss'));

  const [data, setData] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const result = await stationTrendService({ tid: account?.tid, sid: account?.sid, date });
      setData(result);
    };
    fetchData();
  }, [account?.tid, account?.sid, date]);

  const config: any = {
    theme: getThemeStyle(),
    data,
    xField: 'date',
    yField: 'value',
    seriesField: 'name',
    legend: {
      position: 'bottom',
    },
    label: {
      position: 'top',
    },
  };

  return (
    <ProCard
      title="近一周换电电量趋势（度)"
      style={{ height }}
      extra={
        <DatePicker
          defaultValue={moment()}
          onChange={(_value: any, dateString: any) => setDate(dateString)}
        />
      }
    >
      <Line {...config} />
    </ProCard>
  );
};

export default StationTrend;
