import { stationListService } from '@/pages/admin/Station/service';
import { useDictSelect } from '@/utils/dict';
import { Form, Input, InputNumber, Modal, Select } from 'antd';
import _ from 'lodash';
import { useEffect, useState } from 'react';
import { customerListService } from '../Customer/service';
import { vehicleListService } from '../Vehicle/service';
import { batteryAddService, batteryListService } from './service';

const DialogAdd = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await batteryAddService(params);
    if (result?.success) onOk();
  };

  const [list, setList] = useState<any>([]);
  useEffect(() => {
    batteryListService({ tid: current?.tid }).then((result) => setList(result?.data));
  }, [current?.tid]);

  const isEqual = (params: any) =>
    list.some((item: any) => _.isEqual(params, _.pick(item, Object.keys(params))));

  const validator = async (rule: any, value: any) => {
    if (value?.length > 0 && isEqual({ [rule.field]: value })) {
      throw new Error('该编号已存在');
    }
  };

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: current?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [current?.tid]);

  const [place, setPlace] = useState<any>();

  const [vehicles, setVehicles] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await vehicleListService({ tid: current?.tid });
      if (result?.data) setVehicles(result?.data);
    };
    fetchData();
  }, [current?.tid]);

  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await stationListService({ tid: current?.tid });
      if (result?.data) setStations(result?.data);
    };
    fetchData();
  }, [current?.tid]);

  const batteryPlaceSelect = useDictSelect('battery.place');

  return (
    <Modal destroyOnClose title="添加电池" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item label="客户" name="cid" rules={[{ required: true, message: '客户必选' }]}>
          <Select
            placeholder="请选择"
            allowClear
            options={customers.map((item: any) => {
              return { label: item?.name, value: item?.id };
            })}
          />
        </Form.Item>
        <Form.Item
          label="电池编号"
          name="code"
          rules={[{ required: true, message: '电池编号必填' }, { validator }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="当前电量"
          name="level"
          rules={[{ required: true, message: '当前电量必填' }]}
        >
          <InputNumber placeholder="请输入" style={{ width: '100%' }} />
        </Form.Item>
        <Form.Item
          label="电池放置"
          name="place"
          rules={[{ required: true, message: '电池放置必选' }]}
        >
          <Select
            placeholder="请选择"
            options={batteryPlaceSelect}
            allowClear
            onChange={setPlace}
          />
        </Form.Item>
        {place === 'vehicle' && (
          <Form.Item
            label="所在车辆"
            name="vid"
            rules={[{ required: true, message: '所在车辆必选' }]}
          >
            <Select
              placeholder="请选择"
              allowClear
              options={vehicles.map((item: any) => {
                return { label: item?.code, value: item?.id };
              })}
            />
          </Form.Item>
        )}
        {place === 'station' && (
          <Form.Item
            label="所在电站"
            name="sid"
            rules={[{ required: true, message: '所在电站必选' }]}
          >
            <Select
              placeholder="请选择"
              allowClear
              options={stations.map((item: any) => {
                return { label: item?.name, value: item?.id };
              })}
            />
          </Form.Item>
        )}
      </Form>
    </Modal>
  );
};

export default DialogAdd;
