import { useAccount } from '@/utils/hooks';
import { PlusOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button, Modal } from 'antd';
import { useEffect, useRef, useState } from 'react';
import { batteryPageService, batteryRemoveService } from './service';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { customerListService } from '../Customer/service';
import { useDictEnum } from '@/utils/dict';
import { stationListService } from '@/pages/admin/Station/service';
import { vehicleListService } from '../Vehicle/service';

const Page = () => {
  const { account } = useAccount();
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: account?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const [vehicles, setVehicles] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await vehicleListService({ tid: account?.tid });
      if (result?.data) setVehicles(result?.data);
    };
    fetchData();
  }, [account?.tid]);
  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await stationListService({ tid: account?.tid });
      if (result?.data) setStations(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const batteryPlaceEnum = useDictEnum('battery.place');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '客户',
      dataIndex: 'cid',
      valueType: 'select',
      fieldProps: {
        options: customers.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '电池编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '当前电量',
      dataIndex: 'level',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '电池放置',
      dataIndex: 'place',
      valueType: 'select',
      valueEnum: batteryPlaceEnum,
      width: 200,
    },
    {
      title: '所在车辆',
      dataIndex: 'vid',
      valueType: 'select',
      fieldProps: {
        options: vehicles.map((item: any) => {
          return { label: item?.code, value: item?.id };
        }),
      },
      hideInSearch: true,
      width: 200,
    },
    {
      title: '所在电站',
      dataIndex: 'sid',
      valueType: 'select',
      fieldProps: {
        options: stations.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      hideInSearch: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 200,
      render: (_text: any, record: any) => [
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项吗？',
              okType: 'danger',
              onOk: async () => {
                await batteryRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="电池列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({ tid: account?.tid });
              setVisibleAdd(true);
            }}
          >
            <PlusOutlined /> 添加
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await batteryPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
