import { Checkbox, Form, InputNumber, Modal, Select } from 'antd';
import { useEffect, useState } from 'react';
import { customerListService } from '../Customer/service';
import { billMinusService } from './service';

const DialogMinus = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current, notice: true };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await billMinusService(params);
    if (result?.success) onOk();
  };

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: current?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [current?.tid]);

  return (
    <Modal destroyOnClose title="退费" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item label="客户" name="cid" rules={[{ required: true, message: '客户必选' }]}>
          <Select
            placeholder="请选择"
            allowClear
            options={customers.map((item: any) => {
              return { label: item?.name, value: item?.id };
            })}
          />
        </Form.Item>
        <Form.Item
          label="本次金额"
          name="cost"
          rules={[{ required: true, message: '本次金额必填' }]}
        >
          <InputNumber placeholder="请输入" style={{ width: '100%' }} precision={2} />
        </Form.Item>
        <Form.Item name="notice" valuePropName="checked">
          <Checkbox>短信通知客户</Checkbox>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogMinus;
