import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button, Space } from 'antd';
import { useEffect, useRef, useState } from 'react';
import DialogPlus from './DialogPlus';
import DialogMinus from './DialogMinus';
import { billPageService } from './service';
import { customerListService } from '../Customer/service';

const Page = () => {
  const { account } = useAccount();
  const [current, setCurrent] = useState({});
  const [visiblePlus, setVisiblePlus] = useState(false);
  const [visibleMinus, setVisibleMinus] = useState(false);

  const [refresh, setRefresh] = useState(false);
  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: account?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [account?.tid, refresh]);

  const paymentTypeEnum = useDictEnum('payment.type');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '类型',
      dataIndex: 'type',
      valueType: 'select',
      valueEnum: paymentTypeEnum,
      filters: true,
      onFilter: true,
      width: 200,
    },
    {
      title: '客户',
      dataIndex: 'cid',
      valueType: 'select',
      fieldProps: {
        options: customers.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '账户余额',
      dataIndex: 'amount',
      valueType: 'digit',
      render: (_text: any, record: any) => (
        <div>{customers.find((item: any) => item?.id === record?.cid)?.amount}</div>
      ),
      hideInSearch: true,
      width: 200,
    },
    {
      title: '本次金额',
      dataIndex: 'cost',
      valueType: 'digit',
      sorter: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer
      breadcrumbRender={false}
      extra={
        <Space>
          <Button
            key="minus"
            onClick={() => {
              setCurrent({ tid: account?.tid });
              setVisibleMinus(true);
            }}
          >
            退费
          </Button>
          <Button
            key="plus"
            type="primary"
            onClick={() => {
              setCurrent({ tid: account?.tid });
              setVisiblePlus(true);
            }}
          >
            收费
          </Button>
        </Space>
      }
    >
      <ProTable
        headerTitle="费用列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await billPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
      {visiblePlus && (
        <DialogPlus
          visible={visiblePlus}
          current={current}
          onCancel={() => setVisiblePlus(false)}
          onOk={() => {
            setVisiblePlus(false);
            setRefresh(!refresh);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleMinus && (
        <DialogMinus
          visible={visibleMinus}
          current={current}
          onCancel={() => setVisibleMinus(false)}
          onOk={() => {
            setVisibleMinus(false);
            setRefresh(!refresh);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
