import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import { useParams } from '@umijs/max';
import { Button, message, Result } from 'antd';
import { useEffect, useState } from 'react';
import Rule from '../../Rule/Rule';
import { ruleAddService, ruleOneService, ruleRemoveService } from '../../Rule/service';
import { customerEditService, customerIdService } from '../service';

const Page = () => {
  const { id } = useParams<any>();
  const { account } = useAccount();

  const [customer, setCustomer] = useState<any>();
  const [loading, setLoading] = useState(true);
  const [refresh, setRefresh] = useState(true);

  const [flag, setFlag] = useState(true);
  const [current, setCurrent] = useState<any>();

  useEffect(() => {
    const fetchData = async () => {
      setLoading(true);
      if (id) {
        const rc = await customerIdService({ id, tid: account?.tid });
        setCustomer(rc?.data);

        const result = await ruleOneService({ plan: 'custom', cid: id, tid: account?.tid });
        if (result?.data) {
          setFlag(false);
        } else {
          setFlag(true);
        }
        setCurrent({ ...result?.data, plan: 'custom', cid: id, tid: account?.tid });
      }
      setLoading(false);
    };
    fetchData();
  }, [id, account?.tid, refresh]);

  const handleRule = async (plan: string) => {
    const params = { ...customer, plan };
    const result = await customerEditService({ ...params });
    if (result?.success) {
      if (plan === 'operator' && !flag) {
        const result1 = await ruleRemoveService({ ...current });
        if (result1?.success) {
          message.info('移除已有规则');
        }
      }
      if (plan === 'custom' && flag) {
        const query = await ruleOneService({ plan: 'operator', tid: account?.tid });
        const value = { ...query?.data, id: null, plan: 'custom', cid: id, tid: account?.tid };
        const result2 = await ruleAddService({ ...value });
        if (result2?.success) {
          message.info('添加默认规则');
        }
      }
      setRefresh(!refresh);
      message.success('开关规则成功');
    } else {
      message.error('开关规则失败');
    }
  };

  return (
    <PageContainer
      loading={loading}
      onBack={() => window.history.back()}
      breadcrumbRender={false}
      title={customer?.name}
      subTitle="自定义规则"
      extra={
        customer?.plan === 'custom' ? (
          <Button onClick={() => handleRule('operator')}>关闭自定义规则</Button>
        ) : (
          <Button type="primary" onClick={() => handleRule('custom')}>
            开启自定义规则
          </Button>
        )
      }
    >
      {customer?.plan === 'custom' ? (
        <Rule type="custom" flag={flag} current={current} onRefresh={() => setRefresh(!refresh)} />
      ) : (
        <Result
          title="开启自定义规则"
          subTitle="此客户使用的是运营商规则，自定义规则需要自行开启"
        />
      )}
    </PageContainer>
  );
};

export default Page;
