import { useDictSelect } from '@/utils/dict';
import { Form, Input, InputNumber, Modal, Select } from 'antd';
import { customerAddService } from './service';

const DialogAdd = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values, amount: 0, plan: 'operator', status: 'enable' };
    const result = await customerAddService(params);
    if (result?.success) onOk();
  };

  const paymentModeSelect = useDictSelect('payment.mode');

  return (
    <Modal destroyOnClose title="添加客户" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="客户名称"
          name="name"
          rules={[{ required: true, message: '客户名称必填' }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="联系人"
          name="contact"
          rules={[{ required: true, message: '联系人必填' }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="联系手机"
          name="phone"
          rules={[
            { required: true, message: '联系手机必填' },
            { pattern: /^1\d{10}$/, message: '手机格式错误' },
          ]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="付费方式"
          name="mode"
          rules={[{ required: true, message: '付费方式必选' }]}
        >
          <Select placeholder="请选择" options={paymentModeSelect} allowClear />
        </Form.Item>
        <Form.Item
          label="第一预设值"
          name="first"
          rules={[{ required: true, message: '第一预设值必填' }]}
        >
          <InputNumber placeholder="请输入" style={{ width: '100%' }} precision={2} />
        </Form.Item>
        <Form.Item
          label="第二预设值"
          name="second"
          rules={[{ required: true, message: '第二预设值必填' }]}
        >
          <InputNumber placeholder="请输入" style={{ width: '100%' }} precision={2} />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogAdd;
