import { devicePageService } from '@/pages/admin/Device/service';
import { stationListService } from '@/pages/admin/Station/service';
import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { useEffect, useRef, useState } from 'react';

const Page = () => {
  const { account } = useAccount();

  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await stationListService({ tid: account?.tid });
      if (result?.data) setStations(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const deviceTypeEnum = useDictEnum('device.type');
  const deviceStatusEnum = useDictEnum('device.status');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '电站编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '所在电站',
      dataIndex: 'sid',
      valueType: 'select',
      fieldProps: {
        options: stations.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '设备类型',
      dataIndex: 'type',
      valueType: 'select',
      valueEnum: deviceTypeEnum,
      width: 200,
    },
    {
      title: '设备状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: deviceStatusEnum,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="电站设备列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await devicePageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
