import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button } from 'antd';
import { useRef, useState } from 'react';
import { pricePageService } from './service';
import DialogAdd from './DialogAdd';

const Page = () => {
  const { account } = useAccount();
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '电网电价',
      dataIndex: 'unit',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '变动时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="变动电网电价列表"
        tooltip="最后的变动为最新电网电价"
        rowKey="id"
        actionRef={actionRef}
        search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({ tid: account?.tid });
              setVisibleAdd(true);
            }}
          >
            设置电网电价
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await pricePageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
