import { stationPageService } from '@/pages/admin/Station/service';
import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { useRef } from 'react';

const Page = () => {
  const { account } = useAccount();

  const systemStatusEnum = useDictEnum('system.status');

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '电站名称',
      dataIndex: 'name',
      width: 200,
    },
    {
      title: '电站地址',
      dataIndex: 'address',
      hideInSearch: true,
      width: 600,
    },
    {
      title: '电站位置',
      dataIndex: 'location',
      tooltip: '电站的经纬度坐标',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '排队数量',
      dataIndex: 'wait',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: systemStatusEnum,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="电站列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await stationPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
