import { Form, Input, Modal, Select } from 'antd';
import _ from 'lodash';
import { useEffect, useState } from 'react';
import { customerListService } from '../Customer/service';
import { vehicleAddService, vehicleListService } from './service';

const DialogAdd = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await vehicleAddService(params);
    if (result?.success) onOk();
  };

  const [list, setList] = useState<any>([]);
  useEffect(() => {
    vehicleListService({ tid: current?.tid }).then((result) => setList(result?.data));
  }, [current?.tid]);

  const isEqual = (params: any) =>
    list.some((item: any) => _.isEqual(params, _.pick(item, Object.keys(params))));

  const validator = async (rule: any, value: any) => {
    if (value?.length > 0 && isEqual({ [rule.field]: value })) {
      throw new Error('该编号已存在');
    }
  };

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: current?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [current?.tid]);

  return (
    <Modal destroyOnClose title="添加车辆" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item label="客户" name="cid" rules={[{ required: true, message: '客户必选' }]}>
          <Select
            placeholder="请选择"
            allowClear
            options={customers.map((item: any) => {
              return { label: item?.name, value: item?.id };
            })}
          />
        </Form.Item>
        <Form.Item
          label="车辆编号"
          name="code"
          rules={[{ required: true, message: '车辆编号必填' }, { validator }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="车辆位置"
          name="location"
          tooltip={
            <a
              href="https://api.map.baidu.com/lbsapi/getpoint/index.html"
              target="_blank"
              rel="noreferrer"
            >
              点击此处，地图上找经纬度坐标
            </a>
          }
        >
          <Input placeholder="经纬度坐标" allowClear />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogAdd;
