import { useAccount } from '@/utils/hooks';
import { PlusOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button, Modal } from 'antd';
import { useEffect, useRef, useState } from 'react';
import { customerListService } from '../Customer/service';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { vehiclePageService, vehicleRemoveService } from './service';

const Page = () => {
  const { account } = useAccount();
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: account?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '客户',
      dataIndex: 'cid',
      valueType: 'select',
      fieldProps: {
        options: customers.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '车辆编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '车辆位置',
      dataIndex: 'location',
      tooltip: '车辆的经纬度坐标',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 200,
      render: (_text: any, record: any) => [
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项吗？',
              okType: 'danger',
              onOk: async () => {
                await vehicleRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="车辆列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({ tid: account?.tid });
              setVisibleAdd(true);
            }}
          >
            <PlusOutlined /> 添加
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await vehiclePageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ tid: account?.tid }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
