import Footer from '@/components/Footer';
import { useAccount } from '@/utils/hooks';
import { setToken } from '@/utils/token';
import { LockOutlined, MobileOutlined, UserOutlined } from '@ant-design/icons';
import { LoginForm, ProFormCaptcha, ProFormText } from '@ant-design/pro-components';
import { history } from '@umijs/max';
import { message, Tabs } from 'antd';
import { useState } from 'react';
import styles from './index.less';
import { loginAccountService, loginPhoneService, captchaSendService } from './service';

const Login = () => {
  const { queryAccount } = useAccount();
  const [type, setType] = useState<string>('account');

  const handleSubmit = async (values: any) => {
    // 登录
    const result =
      type === 'account' ? await loginAccountService(values) : await loginPhoneService(values);
    if (result?.success) {
      setToken(result?.data);
      await queryAccount();
      const redirect = new URLSearchParams(window.location.search).get('redirect');
      history.push(redirect || '/');
      // window.location.reload();
      message.success('登录成功');
    } else {
      const msg = type === 'account' ? '账户密码错误或被禁用！' : '手机号验证码错误或被禁用！';
      message.error(result?.errorMessage ? result?.errorMessage : msg);
    }
  };

  return (
    <div className={styles.container}>
      <div className={styles.lang} data-lang />
      <div className={styles.content}>
        <LoginForm
          logo={<img alt="logo" src="/chd.png" />}
          title="国海智云"
          subTitle="动力赋能 永续前行"
          initialValues={{
            autoLogin: true,
          }}
          onFinish={async (values) => {
            await handleSubmit(values);
          }}
        >
          <Tabs
            activeKey={type}
            onChange={setType}
            centered
            items={[
              { key: 'account', label: '账号密码登录' },
              { key: 'phone', label: '手机短信登录' },
            ]}
          />
          <div
            style={{
              marginBottom: 16,
            }}
          />
          {type === 'account' && (
            <>
              <ProFormText
                name="account"
                fieldProps={{
                  size: 'large',
                  prefix: <UserOutlined className={styles.prefixIcon} />,
                }}
                placeholder="账号"
                rules={[
                  {
                    required: true,
                    message: '请输入账号',
                  },
                ]}
              />
              <ProFormText.Password
                name="password"
                fieldProps={{
                  size: 'large',
                  prefix: <LockOutlined className={styles.prefixIcon} />,
                }}
                placeholder="密码"
                rules={[
                  {
                    required: true,
                    message: '请输入密码',
                  },
                ]}
              />
            </>
          )}
          {type === 'phone' && (
            <>
              <ProFormText
                fieldProps={{
                  size: 'large',
                  prefix: <MobileOutlined className={styles.prefixIcon} />,
                }}
                name="phone"
                placeholder="手机号"
                rules={[
                  {
                    required: true,
                    message: '请输入手机号',
                  },
                  {
                    pattern: /^1\d{10}$/,
                    message: '手机号格式错误',
                  },
                ]}
              />
              <ProFormCaptcha
                fieldProps={{
                  size: 'large',
                  prefix: <LockOutlined className={styles.prefixIcon} />,
                }}
                captchaProps={{
                  size: 'large',
                }}
                placeholder="验证码"
                captchaTextRender={(timing, count) => {
                  if (timing) {
                    return `${count} 秒后重新获取`;
                  }
                  return '获取验证码';
                }}
                name="captcha"
                rules={[
                  {
                    required: true,
                    message: '请输入验证码',
                  },
                ]}
                phoneName="phone"
                onGetCaptcha={async (phone) => {
                  await captchaSendService({ type: 'login', phone });
                }}
              />
            </>
          )}
          <div
            style={{
              marginBottom: 36,
            }}
          />
        </LoginForm>
      </div>
      <Footer />
    </div>
  );
};

export default Login;
