import { batteryPageService } from '@/pages/operator/Battery/service';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { useRef, useState, useEffect } from 'react';
import { customerListService } from '@/pages/operator/Customer/service';

const Page = () => {
  const { account } = useAccount();

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: account?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '客户',
      dataIndex: 'cid',
      valueType: 'select',
      fieldProps: {
        options: customers.map((item: any) => {
          return { label: item?.name, value: item?.id };
        }),
      },
      width: 200,
    },
    {
      title: '电池编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '电池电量',
      dataIndex: 'level',
      hideInSearch: true,
      width: 200,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="电池列表"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await batteryPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ sid: account?.sid, tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
