import { useAccount } from '@/utils/hooks';
import { textToJson } from '@/utils/utils';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Space, Tag } from 'antd';
import { useRef } from 'react';
import { measurePageService } from './service';

const Page = () => {
  const { account } = useAccount();

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '设备编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '设备参数',
      dataIndex: 'params',
      render: (text: any) => (
        <div>
          {textToJson(text)?.map((item: any) => {
            return (
              <Space key={item?.key}>
                <Tag>
                  {item?.label} : {item?.value}
                </Tag>
              </Space>
            );
          })}
        </div>
      ),
      hideInSearch: true,
      width: 600,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
  ];
  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="设备度量"
        rowKey="id"
        actionRef={actionRef}
        // search={false}
        columns={columns}
        request={async (params, sort) => {
          const { data } = await measurePageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={{ sid: account?.sid, tid: account?.tid }}
      />
    </PageContainer>
  );
};

export default Page;
