import { useDictSelect } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { EditOutlined } from '@ant-design/icons';
import { Divider, Space } from 'antd';
import { useEffect, useState } from 'react';
import ChangeName from './ChangeName';
import ChangePhone from './ChangePhone';
import { userIdService } from './service';

const Information = () => {
  const { account, queryAccount } = useAccount();

  const [visibleName, setVisibleName] = useState(false);
  const [visiblePhone, setVisiblePhone] = useState(false);

  const [refresh, setRefresh] = useState(false);
  const [user, setUser] = useState<any>();
  useEffect(() => {
    const fetchUser = async (params: any) => {
      const result = await userIdService(params);
      if (result?.data) setUser(result?.data);
    };
    fetchUser({ id: account?.id });
  }, [account?.id, refresh]);

  const systemRoleSelect = useDictSelect('system.role');

  const getRole = (role: any) => {
    const name = systemRoleSelect.find((item: any) => item?.value === role)?.label;
    return name ? name : role;
  };

  return (
    <div>
      <div>
        <Space size="middle">
          <span>姓名 :</span>
          <a onClick={() => setVisibleName(true)}>{user?.name ? user?.name : <EditOutlined />}</a>
        </Space>
      </div>
      <Divider />
      <div>
        <Space size="middle">
          <span>手机 :</span>
          <a onClick={() => setVisiblePhone(true)}>
            {user?.phone ? user?.phone : <EditOutlined />}
          </a>
        </Space>
      </div>
      <Divider />
      <div>
        <Space size="middle">
          <span>角色 :</span>
          <span>{getRole(user?.role)}</span>
        </Space>
      </div>
      {visibleName && (
        <ChangeName
          visible={visibleName}
          current={{ id: account?.id, name: user?.name }}
          onCancel={() => setVisibleName(false)}
          onOk={() => {
            setVisibleName(false);
            queryAccount();
            setRefresh(!refresh);
          }}
        />
      )}
      {visiblePhone && (
        <ChangePhone
          visible={visiblePhone}
          current={{ id: account?.id, phone: user?.phone }}
          onCancel={() => setVisiblePhone(false)}
          onOk={() => {
            setVisiblePhone(false);
            queryAccount();
            setRefresh(!refresh);
          }}
        />
      )}
    </div>
  );
};

export default Information;
