import { Form, Input, message, Modal } from 'antd';
import { userChangePasswordService } from './service';

const ChangePassword = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await userChangePasswordService(params);
    if (result?.success) {
      onOk();
    } else {
      message.error('修改失败');
    }
  };

  const validator = async (_: any, value: any) => {
    return !value || form.getFieldValue('newPassword') === value
      ? Promise.resolve()
      : Promise.reject(new Error('确认密码和新密码不一致'));
  };

  return (
    <Modal destroyOnClose title="修改密码" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="原密码"
          name="oldPassword"
          rules={[{ required: true, message: '原密码必填' }]}
        >
          <Input.Password placeholder="请输入" />
        </Form.Item>
        <Form.Item
          label="新密码"
          name="newPassword"
          rules={[{ required: true, message: '新密码必填' }]}
        >
          <Input.Password placeholder="请输入" />
        </Form.Item>
        <Form.Item
          label="确认密码"
          name="confirmPassword"
          rules={[{ required: true, message: '确认密码必填' }, { validator }]}
          dependencies={['newPassword']}
        >
          <Input.Password placeholder="请输入" />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default ChangePassword;
