import { Form, Input, Modal, Select } from 'antd';
import { dictAddService } from './service';

const DialogAdd = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values };
    const result = await dictAddService(params);
    if (result?.success) onOk();
  };

  return (
    <Modal destroyOnClose title="新建字典" open={visible} onCancel={onCancel} onOk={handleSubmit}>
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="分类代码"
          name="category"
          rules={[{ required: true, message: '分类代码必填' }]}
        >
          <Input placeholder="请输入" />
        </Form.Item>
        <Form.Item
          label="分类简介"
          name="brief"
          rules={[{ required: true, message: '分类简介必填' }]}
        >
          <Input placeholder="请输入" />
        </Form.Item>
        <Form.Item
          label="字典编号"
          name="code"
          rules={[{ required: true, message: '字典编号必填' }]}
        >
          <Input placeholder="请输入" />
        </Form.Item>
        <Form.Item
          label="字典名称"
          name="name"
          rules={[{ required: true, message: '字典名称必填' }]}
        >
          <Input placeholder="请输入" />
        </Form.Item>
        <Form.Item label="字典状态" name="status">
          <Select
            placeholder="请选择"
            allowClear
            options={[
              { label: 'default', value: 'default' },
              { label: 'success', value: 'success' },
              { label: 'processing', value: 'processing' },
              { label: 'warning', value: 'warning' },
              { label: 'error', value: 'error' },
            ]}
          />
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default DialogAdd;
