import { PlusOutlined } from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button, Modal } from 'antd';
import { useRef, useState } from 'react';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { dictPageService, dictRemoveService } from './service';

const Page = () => {
  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState<boolean>(false);
  const [visibleEdit, setVisibleEdit] = useState<boolean>(false);

  const actionRef = useRef<ActionType>();
  const columns: ProColumns[] = [
    {
      title: '分类代码',
      dataIndex: 'category',
      width: 200,
    },
    {
      title: '分类简介',
      dataIndex: 'brief',
      width: 200,
    },
    {
      title: '字典编号',
      dataIndex: 'code',
      width: 200,
    },
    {
      title: '字典名称',
      dataIndex: 'name',
      width: 200,
    },
    {
      title: '字典状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: {
        default: { text: 'default', status: 'default' },
        success: { text: 'success', status: 'success' },
        processing: { text: 'processing', status: 'processing' },
        warning: { text: 'warning ', status: 'warning' },
        error: { text: 'error', status: 'error' },
      },
      width: 200,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 200,
      render: (_text: any, record: any) => [
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项内容吗？',
              okType: 'danger',
              onOk: async () => {
                await dictRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];

  return (
    <PageContainer breadcrumbRender={false}>
      <ProTable
        headerTitle="字典列表"
        rowKey="id"
        actionRef={actionRef}
        search={false}
        columns={columns}
        toolBarRender={() => [
          <Button
            key="add"
            type="primary"
            onClick={() => {
              setCurrent({});
              setVisibleAdd(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
        ]}
        request={async (params, sort) => {
          const { data } = await dictPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={current}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={current}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
