import { PageContainer } from '@ant-design/pro-layout';
import { Button, Card, Form, Input, message } from 'antd';
import { settingUpdateService } from './service';

const Page = () => {
  const [form] = Form.useForm();

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { id: 1, content: values.initialPassowrd };
    const result = await settingUpdateService(params);
    if (result?.success) {
      message.success('保存成功！');
    } else {
      message.error('修改失败');
    }
  };

  const validator = async (_: any, value: any) => {
    return !value || form.getFieldValue('initialPassowrd') === value
      ? Promise.resolve()
      : Promise.reject(new Error('确认密码和初始密码不一致'));
  };

  return (
    <PageContainer breadcrumbRender={false} title="系统设置" subTitle="设置初始密码">
      <Card bordered={false}>
        <Form
          style={{ margin: 'auto', marginTop: 8, maxWidth: 600 }}
          layout="vertical"
          form={form}
          initialValues={{}}
          onFinish={handleSubmit}
        >
          <Form.Item
            label="初始密码"
            name="initialPassowrd"
            rules={[{ required: true, message: '初始密码必填' }]}
          >
            <Input.Password placeholder="请输入" />
          </Form.Item>
          <Form.Item
            label="确认密码"
            name="confirmPassword"
            rules={[{ required: true, message: '确认密码必填' }, { validator }]}
            dependencies={['initialPassowrd']}
          >
            <Input.Password placeholder="请输入" />
          </Form.Item>
          <Form.Item>
            <Button type="primary" htmlType="submit">
              保存
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </PageContainer>
  );
};

export default Page;
