import { customerListService } from '@/pages/operator/Customer/service';
import { vehicleListService } from '@/pages/operator/Vehicle/service';
import { stationListService } from '@/pages/admin/Station/service';
import { tenantListService } from '@/pages/admin/Tenant/service';
import { Form, Input, Modal, Select } from 'antd';
import _ from 'lodash';
import { useEffect, useState } from 'react';
import { userAddService, userListService } from './service';

const DialogAdd = ({ visible, current, onCancel, onOk }: any) => {
  const [form] = Form.useForm();
  const initialValues = { ...current };

  const [tempTid, setTempTid] = useState<any>();
  const [tempCid, setTempCid] = useState<any>();

  const [tenant, setTenant] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await tenantListService({});
      if (result?.data) setTenant(result?.data);
    };
    fetchData();
  }, []);

  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      if (tempTid) {
        const result = await stationListService({ tid: tempTid });
        if (result?.data) setStations(result?.data);
      }
    };
    fetchData();
  }, [tempTid]);

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: current?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [current?.tid]);

  const [vchicles, setVchicles] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      if (tempCid) {
        const result = await vehicleListService({ tid: current?.tid, cid: tempCid });
        if (result?.data) setVchicles(result?.data);
      }
    };
    fetchData();
  }, [current?.tid, tempCid]);

  const handleSubmit = async () => {
    const values = await form.validateFields();
    const params = { ...current, ...values, status: 'enable' };
    const result = await userAddService(params);
    if (result?.success) onOk();
  };

  const [list, setList] = useState<any>([]);
  useEffect(() => {
    userListService({}).then((result) => setList(result?.data));
  }, []);

  const isEqual = (params: any) =>
    list.some((item: any) => _.isEqual(params, _.pick(item, Object.keys(params))));

  const validator = async (rule: any, value: any) => {
    if (value?.length > 0 && isEqual({ [rule.field]: value })) {
      throw new Error('该账号已存在');
    }
  };

  const validatorPhone = async (rule: any, value: any) => {
    if (value?.length > 0 && isEqual({ [rule.field]: value })) {
      throw new Error('该手机已存在');
    }
  };

  return (
    <Modal
      destroyOnClose
      title={`添加${current?.title}`}
      open={visible}
      onCancel={onCancel}
      onOk={handleSubmit}
    >
      <Form layout="vertical" form={form} initialValues={initialValues}>
        <Form.Item
          label="账号"
          name="username"
          rules={[{ required: true, message: '账号必填' }, { validator: validator }]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item
          label="手机"
          name="phone"
          rules={[
            { required: true, message: '手机必填' },
            { pattern: /^1\d{10}$/, message: '手机格式错误' },
            { validator: validatorPhone },
          ]}
        >
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        <Form.Item label="姓名" name="name" rules={[{ required: true, message: '姓名必填' }]}>
          <Input placeholder="请输入" allowClear />
        </Form.Item>
        {(current?.role === 'operator' || current?.role === 'station') && (
          <Form.Item
            label="所属运营商"
            name="tid"
            rules={[{ required: true, message: '所属运营商必选' }]}
          >
            <Select
              placeholder="请选择"
              allowClear
              options={tenant.map((item: any) => {
                return { label: item?.name, value: item?.id };
              })}
              onChange={(value) => setTempTid(value)}
            />
          </Form.Item>
        )}
        {current?.role === 'station' && (
          <Form.Item
            label="所属电站"
            name="sid"
            rules={[{ required: true, message: '所属电站必选' }]}
          >
            <Select
              placeholder="请选择"
              allowClear
              options={stations.map((item: any) => {
                return { label: item?.name, value: item?.id };
              })}
            />
          </Form.Item>
        )}
        {(current?.role === 'customer' || current?.role === 'driver') && (
          <Form.Item
            label="所属客户"
            name="cid"
            rules={[{ required: true, message: '所属客户必选' }]}
          >
            <Select
              placeholder="请选择"
              allowClear
              options={customers.map((item: any) => {
                return { label: item?.name, value: item?.id };
              })}
              onChange={(value) => setTempCid(value)}
            />
          </Form.Item>
        )}
        {current?.role === 'driver' && (
          <Form.Item label="绑定车辆" name="vid">
            <Select
              placeholder="请选择"
              allowClear
              options={vchicles.map((item: any) => {
                return { label: item?.code, value: item?.id };
              })}
            />
          </Form.Item>
        )}
      </Form>
    </Modal>
  );
};

export default DialogAdd;
