import { customerListService } from '@/pages/operator/Customer/service';
import { vehicleListService } from '@/pages/operator/Vehicle/service';
import { stationListService } from '@/pages/admin/Station/service';
import { tenantListService } from '@/pages/admin/Tenant/service';
import { useDictEnum } from '@/utils/dict';
import { useAccount } from '@/utils/hooks';
import { PageContainer } from '@ant-design/pro-layout';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import ProTable from '@ant-design/pro-table';
import { Button, Modal, Tabs } from 'antd';
import { useEffect, useRef, useState } from 'react';
import DialogAdd from './DialogAdd';
import DialogEdit from './DialogEdit';
import { userEditService, userPageService, userRemoveService } from './service';

const Page = () => {
  const { account } = useAccount();

  const [current, setCurrent] = useState({});
  const [visibleAdd, setVisibleAdd] = useState(false);
  const [visibleEdit, setVisibleEdit] = useState(false);

  const [tenant, setTenant] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await tenantListService({});
      if (result?.data) setTenant(result?.data);
    };
    fetchData();
  }, []);

  const [stations, setStations] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await stationListService({});
      if (result?.data) setStations(result?.data);
    };
    fetchData();
  }, []);

  const [customers, setCustomers] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await customerListService({ tid: account?.tid });
      if (result?.data) setCustomers(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const [vchicles, setVchicles] = useState<any>([]);
  useEffect(() => {
    const fetchData = async () => {
      const result = await vehicleListService({ tid: account?.tid });
      if (result?.data) setVchicles(result?.data);
    };
    fetchData();
  }, [account?.tid]);

  const tabList = () => {
    if (account?.role === 'admin')
      return [
        { key: 'operator', label: '运营商账户' },
        { key: 'station', label: '站控账户' },
      ];
    if (account?.role === 'operator')
      return [
        { key: 'customer', label: '客户账户' },
        { key: 'driver', label: '司机账户' },
      ];
    return [];
  };

  const initTab = () => {
    if (account?.role === 'admin') return 'operator';
    if (account?.role === 'operator') return 'customer';
    return '';
  };

  const [tab, setTab] = useState(initTab());

  const getTitle = () => {
    if (tab === 'operator') return '运营商账户';
    if (tab === 'station') return '站控账户';
    if (tab === 'customer') return '客户账户';
    if (tab === 'driver') return '司机账户';
    return '';
  };

  const getParams = () => {
    if (tab === 'operator') return { role: 'operator' };
    if (tab === 'station') return { role: 'station' };
    if (tab === 'customer') return { role: 'customer', tid: account?.tid };
    if (tab === 'driver') return { role: 'driver', tid: account?.tid };
    return { role: '' };
  };

  const systemStatusEnum = useDictEnum('system.status');

  const getField = () => {
    const fields: any[] = [];
    if (tab === 'operator') {
      fields.push({
        title: '所属运营商',
        dataIndex: 'tid',
        valueType: 'select',
        fieldProps: {
          options: tenant.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
    }
    if (tab === 'station') {
      fields.push({
        title: '所属运营商',
        dataIndex: 'tid',
        valueType: 'select',
        fieldProps: {
          options: tenant.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
      fields.push({
        title: '所属电站',
        dataIndex: 'sid',
        valueType: 'select',
        fieldProps: {
          options: stations.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
    }
    if (tab === 'customer') {
      fields.push({
        title: '所属运营商',
        dataIndex: 'tid',
        valueType: 'select',
        fieldProps: {
          options: tenant.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
      fields.push({
        title: '所属客户',
        dataIndex: 'cid',
        valueType: 'select',
        fieldProps: {
          options: customers.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
    }
    if (tab === 'driver') {
      fields.push({
        title: '所属运营商',
        dataIndex: 'tid',
        valueType: 'select',
        fieldProps: {
          options: tenant.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
      fields.push({
        title: '所属客户',
        dataIndex: 'cid',
        valueType: 'select',
        fieldProps: {
          options: customers.map((item: any) => {
            return { label: item?.name, value: item?.id };
          }),
        },
        width: 200,
      });
      fields.push({
        title: '绑定车辆',
        dataIndex: 'vid',
        valueType: 'select',
        fieldProps: {
          options: vchicles.map((item: any) => {
            return { label: item?.code, value: item?.id };
          }),
        },
        width: 200,
      });
    }
    return fields;
  };

  const actionRef = useRef<ActionType>();
  const columns: ProColumns<any>[] = [
    {
      title: '账号',
      dataIndex: 'username',
      hideInSearch: true,
      width: 160,
    },
    {
      title: '手机',
      dataIndex: 'phone',
      hideInSearch: true,
      width: 160,
    },
    {
      title: '姓名',
      dataIndex: 'name',
      hideInSearch: true,
      width: 160,
    },
    ...getField(),
    {
      title: '状态',
      dataIndex: 'status',
      valueType: 'select',
      valueEnum: systemStatusEnum,
      width: 160,
    },
    {
      title: '创建时间',
      dataIndex: 'createAt',
      sorter: true,
      hideInSearch: true,
      width: 200,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 200,
      render: (_text: any, record: any) => [
        <a
          key="status"
          onClick={() => {
            Modal.confirm({
              title: '确定修改状态吗？',
              onOk: async () => {
                const params = {
                  ...record,
                  status: record?.status === 'disable' ? 'enable' : 'disable',
                };
                await userEditService(params);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          {record?.status === 'disable' ? '启用' : '禁用'}
        </a>,
        <a
          key="edit"
          onClick={() => {
            setCurrent(record);
            setVisibleEdit(true);
          }}
        >
          编辑
        </a>,
        <a
          key="remove"
          onClick={() => {
            Modal.confirm({
              title: '确定删除该项吗？',
              okType: 'danger',
              onOk: async () => {
                await userRemoveService(record);
                actionRef.current?.reload?.();
              },
            });
          }}
        >
          删除
        </a>,
      ],
    },
  ];

  return (
    <PageContainer
      breadcrumbRender={false}
      header={{
        footer: <Tabs activeKey={tab} items={tabList()} onChange={setTab} />,
      }}
    >
      <ProTable
        headerTitle={`${getTitle()}列表`}
        rowKey="id"
        actionRef={actionRef}
        search={false}
        columns={columns}
        toolBarRender={() => [
          (account?.role === 'admin' || account?.role === 'operator') && (
            <Button
              key="add"
              type="primary"
              onClick={() => {
                setCurrent(getParams());
                setVisibleAdd(true);
              }}
            >
              添加{getTitle()}
            </Button>
          ),
        ]}
        request={async (params, sort) => {
          const { data } = await userPageService({ ...params, sort });
          return { data: data?.list, total: data?.total };
        }}
        params={getParams()}
      />
      {visibleAdd && (
        <DialogAdd
          visible={visibleAdd}
          current={{ ...current, title: getTitle() }}
          onCancel={() => setVisibleAdd(false)}
          onOk={() => {
            setVisibleAdd(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
      {visibleEdit && (
        <DialogEdit
          visible={visibleEdit}
          current={{ ...current, title: getTitle() }}
          onCancel={() => setVisibleEdit(false)}
          onOk={() => {
            setVisibleEdit(false);
            actionRef.current?.reload?.();
          }}
        />
      )}
    </PageContainer>
  );
};

export default Page;
