import { stringify } from 'qs';

function isArray(val: any) {
  return typeof val === 'object' && Object.prototype.toString.call(val) === '[object Array]';
}

function isURLSearchParams(val: any) {
  return typeof URLSearchParams !== 'undefined' && val instanceof URLSearchParams;
}

function isDate(val: any) {
  return typeof val === 'object' && Object.prototype.toString.call(val) === '[object Date]';
}

function isObject(val: any) {
  return val !== null && typeof val === 'object';
}

function forEach2ObjArr(target: any, callback: any) {
  if (!target) return;

  let result = target;
  if (typeof target !== 'object') {
    result = [target];
  }

  if (isArray(result)) {
    for (let i = 0; i < result.length; i++) {
      callback.call(null, result[i], i, result);
    }
  } else {
    for (const key in result) {
      if (Object.prototype.hasOwnProperty.call(result, key)) {
        callback.call(null, result[key], key, result);
      }
    }
  }
}

function paramsStringify(obj: any) {
  return stringify(obj, { arrayFormat: 'repeat', strictNullHandling: true });
}

export function paramsSerialize(params: any, paramsSerializer?: any) {
  let serializedParams;
  let jsonStringifiedParams: any;
  // 支持参数自动拼装，其他 method 也可用，不冲突
  if (params) {
    if (paramsSerializer) {
      serializedParams = paramsSerializer(params);
    } else if (isURLSearchParams(params)) {
      serializedParams = params.toString();
    } else {
      if (isArray(params)) {
        jsonStringifiedParams = [];
        forEach2ObjArr(params, function (item: any) {
          if (item === null || typeof item === 'undefined') {
            jsonStringifiedParams.push(item);
          } else {
            jsonStringifiedParams.push(isObject(item) ? JSON.stringify(item) : item);
          }
        });
        // a: [1,2,3] => a=1&a=2&a=3
        serializedParams = paramsStringify(jsonStringifiedParams);
      } else {
        jsonStringifiedParams = {};
        forEach2ObjArr(params, function (value: any, key: any) {
          let jsonStringifiedValue = value;
          if (value === null || typeof value === 'undefined') {
            jsonStringifiedParams[key] = value;
          } else if (isDate(value)) {
            jsonStringifiedValue = value.toISOString();
          } else if (isArray(value)) {
            jsonStringifiedValue = value;
          } else if (isObject(value)) {
            jsonStringifiedValue = JSON.stringify(value);
          }
          jsonStringifiedParams[key] = jsonStringifiedValue;
        });
        const tmp = paramsStringify(jsonStringifiedParams);
        serializedParams = tmp;
      }
    }
  }
  return serializedParams;
}
